High level Bluetooth Low Energy API and radio abstraction layer

Dependents:   BLE_ANCS_SDAPI BLE_temperature BLE_HeartRate BLE_ANCS_SDAPI_IRC ... more

Overview

The BLE_API is a high level abstraction for using Bluetooth Low Energy on multiple platforms. For details and examples using the BLE_API please see the BLE_API Summary Page. Or click on the API Documentation tab above.

Supported Services

Supported services can be found in the BLE_API/services folder.

Revision:
1122:57dcf7dc2fe8
Parent:
1121:df91547290be
Child:
1123:685c954464e1
--- a/ble/Gap.h	Mon Jan 11 08:52:04 2016 +0000
+++ b/ble/Gap.h	Mon Jan 11 08:52:04 2016 +0000
@@ -129,6 +129,7 @@
     struct Whitelist_t {
         BLEProtocol::Address_t *addresses;
         uint8_t                 size;
+        uint8_t                 capacity;
     };
 
 
@@ -524,7 +525,7 @@
      * advertising or initiating a connection depending on the filter policies.
      *
      * @param[in/out]   whitelist
      *                  (on input) whitelist.size contains the maximum number
      *                  of addresses to be returned.
      *                  (on output) The populated whitelist with copies of the
      *                  addresses in the implementation's whitelist.
@@ -524,7 +525,7 @@
      *
      * @param[in/out]   whitelist
-     *                  (on input) whitelist.size contains the maximum number
+     *                  (on input) whitelist.capacity contains the maximum number
      *                  of addresses to be returned.
      *                  (on output) The populated whitelist with copies of the